# -*- encoding: ascii -*-
"""
Running code formatters
~~~~~~~~~~~~~~~~~~~~~~~

"""

import invoke as _invoke


@_invoke.task(default=True)
def black(ctx, diff=False):
    """Format python code using Black formatter"""
    exe = ctx.shell.frompath('black')
    if exe is None:
        raise RuntimeError("black not found")

    with ctx.shell.root_dir():
        ctx.run(
            ctx.c(
                '%%s %s --config black.toml .'
                % ('--diff --color' if diff else '',),
                exe,
            ),
            echo=True,
        )



# -*- encoding: ascii -*-
"""
Dependencies
~~~~~~~~~~~~

"""

import os as _os

import invoke as _invoke


@_invoke.task()
def old(ctx):
    """ List outdated python packages """
    with ctx.shell.root_dir():
        ctx.run('pip list -o', echo=True)


@_invoke.task()
def package(ctx, upgrade=False):
    """ Update python dependencies, excluding development """
    with ctx.shell.root_dir():
        ctx.run('pip install %s-e .' % ('-U ' if upgrade else '',), echo=True)


@_invoke.task(default=True)
def dev(ctx, upgrade=False):
    """ Update python dependencies, including development """
    with ctx.shell.root_dir():
        ctx.run('pip install %s-r development.txt'
                % ('-U ' if upgrade else '',), echo=True)


@_invoke.task()
def reset(ctx, python=False, upgrade=False):
    """ Reset your virtual env """
    cmd = "bash -il %s/reset.sh"
    if python:
        cmd += ' -p'
    if upgrade:
        cmd += ' -u'
    cmd += ' %s'
    with ctx.shell.root_dir():
        pwd = _os.getcwd()
        ctx.run(ctx.c(cmd, ctx.shell.native(_os.path.dirname(__file__)), pwd),
                pty=True)



# -*- coding: ascii -*-
u"""
=================================
 Benchmark cssmin implementations
=================================

Benchmark cssmin implementations.

:Copyright:

 Copyright 2011 - 2023
 Andr\xe9 Malo or his licensors, as applicable

:License:

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

"""
